==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleCloudwatchAlarmArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property alarmName The CloudWatch alarm name.
 * @property roleArn The IAM role ARN that allows access to the CloudWatch alarm.
 * @property stateReason The reason for the alarm change.
 * @property stateValue The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
 */
public data class TopicRuleCloudwatchAlarmArgs(
    public val alarmName: Output<String>,
    public val roleArn: Output<String>,
    public val stateReason: Output<String>,
    public val stateValue: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs =
        com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs.builder()
            .alarmName(alarmName.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .stateReason(stateReason.applyValue({ args0 -> args0 }))
            .stateValue(stateValue.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleCloudwatchAlarmArgs].
 */
@PulumiTagMarker
public class TopicRuleCloudwatchAlarmArgsBuilder internal constructor() {
    private var alarmName: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var stateReason: Output<String>? = null

    private var stateValue: Output<String>? = null

    /**
     * @param value The CloudWatch alarm name.
     */
    @JvmName("kkpqqueejkinxoyw")
    public suspend fun alarmName(`value`: Output<String>) {
        this.alarmName = value
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch alarm.
     */
    @JvmName("hettahpqjwdglxay")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The reason for the alarm change.
     */
    @JvmName("jbogeuooxwixnqnf")
    public suspend fun stateReason(`value`: Output<String>) {
        this.stateReason = value
    }

    /**
     * @param value The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
     */
    @JvmName("qpjavvmhvtmryora")
    public suspend fun stateValue(`value`: Output<String>) {
        this.stateValue = value
    }

    /**
     * @param value The CloudWatch alarm name.
     */
    @JvmName("edoeuifrskomafna")
    public suspend fun alarmName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.alarmName = mapped
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch alarm.
     */
    @JvmName("sbelpmollgatjbay")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value The reason for the alarm change.
     */
    @JvmName("rpxgskmyeelbhsfl")
    public suspend fun stateReason(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.stateReason = mapped
    }

    /**
     * @param value The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
     */
    @JvmName("bhgaahqcdihixnuk")
    public suspend fun stateValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.stateValue = mapped
    }

    internal fun build(): TopicRuleCloudwatchAlarmArgs = TopicRuleCloudwatchAlarmArgs(
        alarmName = alarmName ?: throw PulumiNullFieldException("alarmName"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        stateReason = stateReason ?: throw PulumiNullFieldException("stateReason"),
        stateValue = stateValue ?: throw PulumiNullFieldException("stateValue"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleCloudwatchAlarmArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property alarmName The CloudWatch alarm name.
 * @property roleArn The IAM role ARN that allows access to the CloudWatch alarm.
 * @property stateReason The reason for the alarm change.
 * @property stateValue The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
 */
public data class TopicRuleCloudwatchAlarmArgs(
    public val alarmName: Output<String>,
    public val roleArn: Output<String>,
    public val stateReason: Output<String>,
    public val stateValue: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs =
        com.pulumi.aws.iot.inputs.TopicRuleCloudwatchAlarmArgs.builder()
            .alarmName(alarmName.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 }))
            .stateReason(stateReason.applyValue({ args0 -> args0 }))
            .stateValue(stateValue.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleCloudwatchAlarmArgs].
 */
@PulumiTagMarker
public class TopicRuleCloudwatchAlarmArgsBuilder internal constructor() {
    private var alarmName: Output<String>? = null

    private var roleArn: Output<String>? = null

    private var stateReason: Output<String>? = null

    private var stateValue: Output<String>? = null

    /**
     * @param value The CloudWatch alarm name.
     */
    @JvmName("xsiwygqftxbdrpnw")
    public suspend fun alarmName(`value`: Output<String>) {
        this.alarmName = value
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch alarm.
     */
    @JvmName("hxiokejtknlucqrq")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The reason for the alarm change.
     */
    @JvmName("llurcvllwsaceixw")
    public suspend fun stateReason(`value`: Output<String>) {
        this.stateReason = value
    }

    /**
     * @param value The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
     */
    @JvmName("maegdqqrogtbnmkc")
    public suspend fun stateValue(`value`: Output<String>) {
        this.stateValue = value
    }

    /**
     * @param value The CloudWatch alarm name.
     */
    @JvmName("oqjcdeilycelqjat")
    public suspend fun alarmName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.alarmName = mapped
    }

    /**
     * @param value The IAM role ARN that allows access to the CloudWatch alarm.
     */
    @JvmName("uwpaqxyqaiqjuhlo")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    /**
     * @param value The reason for the alarm change.
     */
    @JvmName("ojevvwbsethgmpkm")
    public suspend fun stateReason(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.stateReason = mapped
    }

    /**
     * @param value The value of the alarm state. Acceptable values are: OK, ALARM, INSUFFICIENT_DATA.
     */
    @JvmName("gagkgsetfxjwaycg")
    public suspend fun stateValue(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.stateValue = mapped
    }

    internal fun build(): TopicRuleCloudwatchAlarmArgs = TopicRuleCloudwatchAlarmArgs(
        alarmName = alarmName ?: throw PulumiNullFieldException("alarmName"),
        roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        stateReason = stateReason ?: throw PulumiNullFieldException("stateReason"),
        stateValue = stateValue ?: throw PulumiNullFieldException("stateValue"),
    )
}
